"""authprojectname

This file loads the finished app from authprojectname.config.middleware.
"""
from authprojectname.config.middleware import make_app
